@@ -40,32 +40,39 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '13.4.4.5.js';
+gTestfile = '13.4.4.31.js';
 
-START("13.4.4.5 - XML attributes()");
+START("13.4.4.31 - XML removeNamespace()");
 
-TEST(1, true, XML.prototype.hasOwnProperty("attributes"));
+TEST(1, true, XML.prototype.hasOwnProperty("removeNamespace"));
 
 x =
-<alpha attr1="value1" attr2="value2" attr3="value3">
+<alpha xmlns:foo="http://foo/">
     <bravo>one</bravo>
 </alpha>;
 
-TEST(2, "xml", typeof(x.attributes()));
-
-// Iterate through the attributes of an XML value
-x =
-<alpha attr1="value1" attr2="value2" attr3="value3">
+correct =
+<alpha>
     <bravo>one</bravo>
 </alpha>;
 
-correct = new Array("value1", "value2", "value3");
-i = 0;
+x.removeNamespace("http://foo/");
 
-for each (var a in x.attributes())
-{
-    TEST_XML(i + 3, correct[i], a);
-    i++;
-}
+TEST(2, correct, x);
+
+// Shouldn't remove namespace if referenced
+x =
+<foo:alpha xmlns:foo="http://foo/">
+    <bravo>one</bravo>
+</foo:alpha>;
+
+correct =
+<foo:alpha xmlns:foo="http://foo/">
+    <bravo>one</bravo>
+</foo:alpha>;
+
+x.removeNamespace("http://foo/");
+
+TEST(3, correct, x);
 
 END();
\ No newline at end of file
