@@ -35,31 +35,20 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-470300-02.js';
+var gTestfile = 'regress-455464-01.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 470300;
-var summary = 'TM: Do not assert: !fp->blockChain || OBJ_GET_PARENT(cx, obj) == fp->blockChain';
-var actual = '';
-var expect = '';
+var BUGNUMBER = 455464;
+var summary = 'Do not assert with JIT: !TRACE_RECORDER(cx) ^ (jumpTable == recordingJumpTable)';
+var actual = 'No Crash';
+var expect = 'No Crash';
 
+printBugNumber(BUGNUMBER);
+printStatus (summary);
 
-//-----------------------------------------------------------------------------
-test();
-//-----------------------------------------------------------------------------
+jit(true);
 
-function test()
-{
-  enterFunc ('test');
-  printBugNumber(BUGNUMBER);
-  printStatus (summary);
- 
-  jit(true);
+a=b=c=d=0; this.__defineGetter__('g', gc); for each (y in this);
 
-  for (let a = 0; a < 7; ++a) { let e = 8; if (a > 3) { let x; } }
+jit(false);
 
-  jit(false);
-
-  reportCompare(expect, actual, summary);
-
-  exitFunc ('test');
-}
+reportCompare(expect, actual, summary);
