@@ -19,7 +19,7 @@
  * Portions created by the Initial Developer are Copyright (C) 2008
  * the Initial Developer. All Rights Reserved.
  *
- * Contributor(s): Jesse Ruderman
+ * Contributor(s): Brendan Eich
  *
  * Alternatively, the contents of this file may be used under the terms of
  * either the GNU General Public License Version 2 or later (the "GPL"), or
@@ -35,10 +35,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-var gTestfile = 'regress-465460-02.js';
+var gTestfile = 'regress-452498-027.js';
 //-----------------------------------------------------------------------------
-var BUGNUMBER = 465460;
-var summary = 'TM: valueOf in a loop: do not assert';
+var BUGNUMBER = 452498;
+var summary = 'TM: upvar2 regression tests';
 var actual = '';
 var expect = '';
 
@@ -52,14 +52,20 @@ function test()
   enterFunc ('test');
   printBugNumber(BUGNUMBER);
   printStatus (summary);
- 
-  jit(true);
 
-  for each (let c in [null, null, null, {}]) { }
+  expect = '5';
 
-  jit(false);
+// ------- Comment #27 From Brendan Eich
+
+  function f(x){function g(y)x+y;return g}
+  g = f(2);
+
+  actual = String(g(3));
 
   reportCompare(expect, actual, summary);
 
   exitFunc ('test');
 }
+
+
+
